package com.muyu.server.service.impl;

import cn.hutool.core.map.MapUtil;
import com.muyu.cache.EnterpriseCacheService;
import com.muyu.common.domain.Enterprise;
import com.muyu.common.util.PageUtils;
import com.muyu.server.mapper.EnterpriseDao;
import com.muyu.server.service.EnterpriseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @Author YuPing
 * @Description 企业运营实现层
 * @Version 1.0
 * @Data 2024-09-26 20:23:21
 */
@Service
public class EnterpriseServiceImpl implements EnterpriseService {

    @Autowired
    private EnterpriseDao enterpriseDao;

    @Autowired
    private EnterpriseCacheService enterpriseCacheService;

    /**
     * 分页查询企业运营信息
     * @param param
     * @return
     */
    @Override
    public PageUtils selectEnterprise(Map param) {
        ArrayList<HashMap> list = new ArrayList<>();
        long count = enterpriseDao.selectEnterpriseCount();
        if (count > 0){
            list = enterpriseDao.selectEnterprise(param);
        }
        int page = MapUtil.getInt(param, "page");
        int length = MapUtil.getInt(param,"length");
        PageUtils pageUtils = new PageUtils(list, count, page, length);
        return pageUtils;
    }


    /**
     * 新增企业信息
     * @param enterprise
     * @return
     */
    @Override
    public int insert(Enterprise enterprise) {
        int rows = enterpriseDao.insert(enterprise);
        if (rows > 0){
            enterpriseCacheService.put(String.valueOf(enterprise.getEnterpriseId()), enterprise);
        }
        return rows;
    }


    /**
     * 根据编号查询企业信息
     * @param enterpriseId
     * @return
     */
    @Override
    public HashMap searchById(int enterpriseId) {
        HashMap map = enterpriseDao.searchById(enterpriseId);
        if (map != null){
            Enterprise enterprise = enterpriseCacheService.get(String.valueOf(enterpriseId));
            if (enterprise != null){
                map.put("enterprise", enterprise);
            }
        }
        return map;
    }


    /**
     * 修改企业信息
     * @param enterprise
     * @return
     */
    @Override
    public int updateEnterprise(Enterprise enterprise) {
        int rows = enterpriseDao.updateEnterprise(enterprise);
        if (rows > 0){
            enterpriseCacheService.put(String.valueOf(enterprise.getEnterpriseId()), enterprise);
        }
        return rows;
    }


    /**
     * 删除企业信息
     * @param ids
     * @return
     */
    @Override
    public int deleteByIds(Integer[] ids) {
        if (ids == null || ids.length == 0) {
            throw new IllegalArgumentException("请选择要删除的企业名称编号");
        }

        Integer[] idList = Arrays.asList(ids).toArray(new Integer[0]);
        int rows = enterpriseDao.deleteByIds(idList);
        enterpriseCacheService.remove(String.valueOf(idList));
        return rows;

    }
}
